@@ -5,14 +5,15 @@ Main file for this code. The main code is in `select`, and the rest is to help w
 import warnings
 
 from numbers import Number
-from typing import Optional
+from typing import Optional, Sequence, Tuple, Union
 
 import cf_xarray  # noqa: F401
 import numpy as np
 import xarray as xr
 import xoak  # noqa: F401
 
-from xarray import DataArray
+from dask.delayed import Delayed
+from xarray import DataArray, Dataset
 
 
 try:
@@ -32,14 +33,14 @@ except ImportError:  # pragma: no cover
 
 
 def interp_multi_dim(
-    da,
-    da_out=None,
-    T=None,
-    Z=None,
-    iT=None,
-    iZ=None,
-    extrap_method=None,
-    locstream=False,
+    da: DataArray,
+    da_out: Optional[DataArray] = None,
+    T: Optional[Union[str, list]] = None,
+    Z: Optional[Union[str, list]] = None,
+    iT: Optional[Union[int, list]] = None,
+    iZ: Optional[Union[int, list]] = None,
+    extrap_method: Optional[str] = None,
+    locstream: bool = False,
     weights=None,
 ):
     """Interpolate input DataArray to output DataArray using xESMF.
@@ -371,7 +372,10 @@ def select(
 
 
 def sel2d(
-    var, mask: Optional[DataArray] = None, distances_name: str = "distance", **kwargs
+    var,
+    mask: Optional[DataArray] = None,
+    distances_name: Optional[str] = None,
+    **kwargs,
 ):
     """Find the value of the var at closest location to inputs, optionally respecting mask.
 
@@ -399,7 +403,7 @@ def sel2d(
     mask : DataArray, optional
         If input, mask is applied to lon/lat so that if requested lon/lat is on land, the nearest valid model point will be returned. Otherwise nan's will be returned. If requested lon/lat is outside domain but not on land, the nearest model output will be returned regardless.
     distances_name : str, optional
-        Provide a name in which to save the distances from xoak; there will be one per lon/lat location found. If None, distances won't be returned in object.
+        Provide a name in which to save the distances from xoak; there will be one value per lon/lat location found. If None, distances won't be returned in object.
 
     Returns
     -------
@@ -412,13 +416,16 @@ def sel2d(
     Examples
     --------
     Select grid node of DataArray nearest to location (-96, 27). The DataArray `ds.temp` has coordinates `lon_rho` and `lat_rho`:
+
     >>> da = ds.temp
     >>> em.sel2d(da, lon_rho=-96, lat_rho=27)
 
     To additionally select from the time and depth dimensions, call as:
+
     >>> em.sel2d(da, lon_rho=-96, lat_rho=27, time='2022-07-19', s_rho=0.0)
 
     You may also input other keywords to pass onto `xarray.sel()`:
+
     >>> em.sel2d(da, lon_rho=-96, lat_rho=27, s_rho=0.0, method='nearest')
     """
 
@@ -448,13 +455,18 @@ def sel2d(
 
     # 1D or 2D
     if lons.ndim == lats.ndim == 1:
-        dims = "loc"
+        dims = ("loc",)
     elif lons.ndim == lats.ndim == 2:
         dims = ("loc_y", "loc_x")
     # else: Raise exception
 
     # create Dataset
-    ds_to_find = xr.Dataset({"lat_to_find": (dims, lats), "lon_to_find": (dims, lons)})
+    ds_to_find = xr.Dataset(
+        {
+            "lat_to_find": (dims, lats, {"standard_name": "latitude"}),
+            "lon_to_find": (dims, lons, {"standard_name": "longitude"}),
+        }
+    )
 
     if mask is not None:
 
@@ -486,20 +498,49 @@ def sel2d(
 
     # perform selection
     output = var.xoak.sel(
-        {latname: ds_to_find.lat_to_find, lonname: ds_to_find.lon_to_find},
-        distances_name=distances_name,
+        {latname: ds_to_find.lat_to_find, lonname: ds_to_find.lon_to_find}
     )
+    # # this version is for the updates in xoak
+    # output = var.xoak.sel(
+    #     {latname: ds_to_find.lat_to_find, lonname: ds_to_find.lon_to_find},
+    #     distances_name=distances_name,
+    # )
+    # output[distances_name] *= 6371  # convert from radians to km
 
-    # distances between input points and nearest points
-    # distances = var.xoak._index.query(np.array([*zip(lats,lons)]))['distances'][:,0]
-    # import pdb; pdb.set_trace()
+    if distances_name is not None:
+        # only calculate distances this way (outside of xoak itself) if not doing 2D since we just need distances
+        # right now for OMSA and don't want a separate soln from xoak for this problem
+        if ds_to_find.lat_to_find.ndim > 1:
+            with xr.set_options(keep_attrs=True):
+                return output.sel(**kwargs)
+
+        # distances between input points and nearest points - this won'tbe needed with new version of xoak once merged
+        # * 6371 to convert from radians to km
+        index = var.xoak._index
+        if isinstance(index, tuple):
+            index = index[0]
+        distances = index.query(np.array([*zip(lats, lons)]))["distances"][:, 0] * 6371
+        if isinstance(distances, Delayed):
+            # import pdb; pdb.set_trace()
+            distances = distances.compute()
+        if not isinstance(output, Dataset):
+            output = output.to_dataset()
+        attrs = {"units": "km"}
+        indexer_dim = ds_to_find.lat_to_find.dims
+        indexer_shape = ds_to_find.lat_to_find.shape
+        output[distances_name] = xr.Variable(
+            indexer_dim, distances.reshape(indexer_shape), attrs
+        )
 
     with xr.set_options(keep_attrs=True):
         return output.sel(**kwargs)
 
 
 def sel2dcf(
-    var, mask: Optional[DataArray] = None, distances_name: str = "distance", **kwargs
+    var,
+    mask: Optional[DataArray] = None,
+    distances_name: Optional[str] = None,
+    **kwargs,
 ):
     """Find nearest value(s) on 2D horizontal grid using cf-xarray names.
 
@@ -512,13 +553,16 @@ def sel2dcf(
     Examples
     --------
     Select grid node of DataArray nearest to location (-96, 27):
+
     >>> da = ds.temp
     >>> em.sel2d(da, longitude=-96, latitude=27)
 
     To additionally select from the time and depth dimensions, call as:
+
     >>> em.sel2d(da, longitude=-96, latitude=27, T='2022-07-19', Z=0.0)
 
     You may also input other keywords to pass onto `xarray.sel()`:
+
     >>> em.sel2d(da, longitude=-96, latitude=27, Z=0.0, method='nearest')
     """
 
